ginebra2/RecentUrlToolbarSnippet.cpp
changeset 12 afcd8e6d025b
parent 3 0954f5dd2cd0
child 16 3c88a81ff781
--- a/ginebra2/RecentUrlToolbarSnippet.cpp	Wed Sep 01 13:56:21 2010 -0400
+++ b/ginebra2/RecentUrlToolbarSnippet.cpp	Fri Sep 17 12:11:40 2010 -0400
@@ -25,7 +25,7 @@
 #include "ToolbarChromeItem.h"
 #include "ViewStack.h"
 #include "GWebContentView.h"
-#include "BookmarksManager.h"
+#include "HistoryManager.h"
 #include <QDebug>
 
 namespace GVA {
@@ -35,6 +35,7 @@
         : DualButtonToolbarSnippet(elementId, chrome, element),
           m_action1(0)
     {      
+        connect(m_chrome, SIGNAL(aspectChanged(int)) , this, SLOT(onAspectChanged()));    	
     }
 
     RecentUrlToolbarSnippet::~RecentUrlToolbarSnippet()
@@ -43,6 +44,10 @@
             delete m_action1;
     }
 
+     void RecentUrlToolbarSnippet::onAspectChanged( ) {
+    	 
+        updateOwnerArea();      
+     }     
     RecentUrlToolbarSnippet * RecentUrlToolbarSnippet::instance(const QString& elementId, ChromeWidget * chrome, const QWebElement & element)
     {
         RecentUrlToolbarSnippet * that = new RecentUrlToolbarSnippet( elementId, chrome, element );
@@ -94,8 +99,8 @@
             }
             else if (t->actionId == RECENTURL_VIEW_ACTION_CLEARALL) {
                 if( !action ) {
-					// Action is created/handled/owned by BookmarksManager
-                    QAction * a = WRT::BookmarksManager::getSingleton()->getActionClearHistory();
+					// Action is created/handled/owned by HistoryManager
+                    QAction * a = WRT::HistoryManager::getSingleton()->getActionClearHistory();
                     button->setDefaultAction(a);
                 }
             }